@@ -233,12 +233,25 @@ def postprocess(new_lv):
         log.debug("Running ldconfig on new layer")
         utils.ExternalBinary().ldconfig(["-r", new_fs.path("/")])
 
+    def _install_update_rpm():
+        update_rpm = os.getenv("IMGBASED_IMAGE_UPDATE_RPM")
+        if not update_rpm:
+            return
+        # Grab the first update rpm
+        rpms = list(set(update_rpm.splitlines()))
+        if len(rpms) > 1:
+            log.warn("Received multiple update rpms %s", rpms)
+        log.debug("Installing image-update rpm from %s", rpms[0])
+        utils.ExternalBinary().rpm(["-U", "--quiet", "--justdb", "--root",
+                                    new_fs.path("/"), rpms[0]])
+
     with mounted(new_lv.path) as new_fs:
         _reconfigure_vdsm()
         _apply_scap_profile()
         _permit_root_login()
         _disable_os_probes()
         _run_ldconfig()
+        _install_update_rpm()
     _clear_libvirt_cache()
 
 
